# eric7.eric7_browser

eric Web Browser.

This is the main Python script that performs the necessary initialization of the web browser and starts the Qt event loop. This is a standalone version of the integrated web browser. It is based on QtWebEngine.

### Global Attributes

SettingsDir
app

### Classes

None

### Functions

createMainWidget | Function to create the main widget.
main | Main entry point into the application.

## createMainWidget

createMainWidget(argv)

Function to create the main widget.

argv (list of str)
  list of command line parameters

Return:
  reference to the main widget

Return Type:
  QWidget

Up

## main

main()

Main entry point into the application.

Up